function [pnt,du]=dnurbscrv(cpc,n,k,t,w,u)
% FUNCTION:
% Calculate 1st order derivative at evaluated point on a NURBS curve
% based on parameter u
%+++++++++++++++++++++++++++++++++++++++
% INPUT:
% n==> # of cp -1;
% cpc==> cp cartesian coordinates matrix, 3X(n+1) matrix;
% k==> order;
% t==> knot row vector;
% w==> weight row vector;
% u==> parameter value at evaluated point;
%++++++++++++++++++++++++++++++++++++++++
% OUTPUT:
% pnt==> cartesian coordinates of evaluated point, 3X1 vector;
% drv==> 1st order derivative  at evaluated point,  3X1 vector;
%++++++++++++++++++++++++++++++++++++++++

cph=cat(1,cpc.*repmat(w,3,1),w);

for j=1:(n+k)
    if t(j)<=u&&u<t(j+1)
        l=j;
        break;
    end
    if u==1
        l=n+1;
        break;
    end
end
dbw1=coxdeboor(w',t,k,l,u);
dbdw2=coxdeboord(w',t,k,l,u);
dbwp3=coxdeboor(cph(1:3,:)',t,k,l,u);
dbdwp4=coxdeboord(cph(1:3,:)',t,k,l,u);
dbwp=coxdeboor(cph',t,k,l,u);
pnt=(dbwp3./repmat(dbwp(:,4),1,3))';
du=(1/dbw1^2)*(dbw1*dbdwp4-dbdw2*dbwp3)';