function [pt] = surf_pnt(nurbs,tt)

% surf_pnt computes a point on a NURBS surface
% of degree (p,q) at given parameter values (t,s). The surface is
% defined by the control net nurbs.coefs and the sequences of knots U and V.

t = tt{1};
s = tt{2};

p =  nurbs.order(1) - 1;
q =  nurbs.order(2) - 1;

U = nurbs.knots{1};
V = nurbs.knots{2};

m1 = size(U, 2);
m2 = size(V, 2);

n1 = size(nurbs.coefs, 2);
n2 = size(nurbs.coefs, 3);

if (m1 ~= (n1 + p + 1))
  error('Inconsistency between number of knots, control points and surface degree');
end

if (m2 ~= (n2 + q + 1))
  error('Inconsistency between number of knots, control points and surface degree');
end

if  t>=U(n1+1),
    span = n1 - 1;
else if t<=U(p+1),
        span = p;
    else
        span = 0;
        while t>U(span+1)
            span = span+1;
        end
        span = span - 1;
    end
end
i = span;

if  s>=V(n2+1),
    span = n2 - 1;
else if s<=V(q+1),
        span = q;
    else
        span = 0;
        while s>V(span+1)
            span = span+1;
        end
        span = span - 1;
    end
end
j = span;

Nt = Basisfuns(t,U,i,p+1);
Ns = Basisfuns(s,V,j,q+1);

tind = i - p - 1;
sind = j - q - 1;

pt1 = zeros(size(nurbs.coefs,1),1);
for l = 0 : q    
    for k = 0 : p 
        pt1 = pt1 +  Ns(l+1) * Nt(k+1) * nurbs.coefs(:,i-p+1+k,j-q+1+l);
    end
end

if size(nurbs.coefs,1) == 4,
    pt =  pt1(1:3,:,:)./pt1(4,:,:);
else
    pt =  pt1;
end




